# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetLocalReferenceResult',
    'AwaitableGetLocalReferenceResult',
    'get_local_reference',
    'get_local_reference_output',
]

@pulumi.output_type
class GetLocalReferenceResult:
    """
    The result of fetching from a Terraform state store.
    """
    def __init__(__self__, outputs=None):
        if outputs and not isinstance(outputs, dict):
            raise TypeError("Expected argument 'outputs' to be a dict")
        pulumi.set(__self__, "outputs", outputs)

    @property
    @pulumi.getter
    def outputs(self) -> Mapping[str, Any]:
        """
        The outputs displayed from Terraform state.
        """
        return pulumi.get(self, "outputs")


class AwaitableGetLocalReferenceResult(GetLocalReferenceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLocalReferenceResult(
            outputs=self.outputs)


def get_local_reference(path: Optional[builtins.str] = None,
                        workspace_dir: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLocalReferenceResult:
    """
    Access state from the local filesystem.


    :param builtins.str path: The path to the tfstate file. This defaults to "terraform.tfstate" relative to the root module by default.
    :param builtins.str workspace_dir: The path to non-default workspaces.
    """
    __args__ = dict()
    __args__['path'] = path
    __args__['workspaceDir'] = workspace_dir
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('terraform:state:getLocalReference', __args__, opts=opts, typ=GetLocalReferenceResult).value

    return AwaitableGetLocalReferenceResult(
        outputs=pulumi.get(__ret__, 'outputs'))
def get_local_reference_output(path: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               workspace_dir: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLocalReferenceResult]:
    """
    Access state from the local filesystem.


    :param builtins.str path: The path to the tfstate file. This defaults to "terraform.tfstate" relative to the root module by default.
    :param builtins.str workspace_dir: The path to non-default workspaces.
    """
    __args__ = dict()
    __args__['path'] = path
    __args__['workspaceDir'] = workspace_dir
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('terraform:state:getLocalReference', __args__, opts=opts, typ=GetLocalReferenceResult)
    return __ret__.apply(lambda __response__: GetLocalReferenceResult(
        outputs=pulumi.get(__response__, 'outputs')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'Workspaces',
    'WorkspacesDict',
]

MYPY = False

if not MYPY:
    class WorkspacesDict(TypedDict):
        name: NotRequired[builtins.str]
        """
        The full name of one remote workspace. When configured, only the default workspace can be used. This option conflicts with prefix.
        """
        prefix: NotRequired[builtins.str]
        """
        A prefix used in the names of one or more remote workspaces, all of which can be used with this configuration. The full workspace names are used in HCP Terraform, and the short names (minus the prefix) are used on the command line for Terraform CLI workspaces. If omitted, only the default workspace can be used. This option conflicts with name.
        """
elif False:
    WorkspacesDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class Workspaces:
    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 prefix: Optional[builtins.str] = None):
        """
        :param builtins.str name: The full name of one remote workspace. When configured, only the default workspace can be used. This option conflicts with prefix.
        :param builtins.str prefix: A prefix used in the names of one or more remote workspaces, all of which can be used with this configuration. The full workspace names are used in HCP Terraform, and the short names (minus the prefix) are used on the command line for Terraform CLI workspaces. If omitted, only the default workspace can be used. This option conflicts with name.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if prefix is not None:
            pulumi.set(__self__, "prefix", prefix)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        The full name of one remote workspace. When configured, only the default workspace can be used. This option conflicts with prefix.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def prefix(self) -> Optional[builtins.str]:
        """
        A prefix used in the names of one or more remote workspaces, all of which can be used with this configuration. The full workspace names are used in HCP Terraform, and the short names (minus the prefix) are used on the command line for Terraform CLI workspaces. If omitted, only the default workspace can be used. This option conflicts with name.
        """
        return pulumi.get(self, "prefix")

    @prefix.setter
    def prefix(self, value: Optional[builtins.str]):
        pulumi.set(self, "prefix", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_terraform.state as __state
    state = __state
else:
    state = _utilities.lazy_import('pulumi_terraform.state')

_utilities.register(
    resource_modules="""
[]
""",
    resource_packages="""
[
 {
  "pkg": "terraform",
  "token": "pulumi:providers:terraform",
  "fqn": "pulumi_terraform",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from ._inputs import *

__all__ = [
    'GetRemoteReferenceResult',
    'AwaitableGetRemoteReferenceResult',
    'get_remote_reference',
    'get_remote_reference_output',
]

@pulumi.output_type
class GetRemoteReferenceResult:
    """
    The result of fetching from a Terraform state store.
    """
    def __init__(__self__, outputs=None):
        if outputs and not isinstance(outputs, dict):
            raise TypeError("Expected argument 'outputs' to be a dict")
        pulumi.set(__self__, "outputs", outputs)

    @property
    @pulumi.getter
    def outputs(self) -> Mapping[str, Any]:
        """
        The outputs displayed from Terraform state.
        """
        return pulumi.get(self, "outputs")


class AwaitableGetRemoteReferenceResult(GetRemoteReferenceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRemoteReferenceResult(
            outputs=self.outputs)


def get_remote_reference(hostname: Optional[builtins.str] = None,
                         organization: Optional[builtins.str] = None,
                         token: Optional[builtins.str] = None,
                         workspaces: Optional[Union['Workspaces', 'WorkspacesDict']] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRemoteReferenceResult:
    """
    Access state from a remote backend.


    :param builtins.str hostname: The remote backend hostname to connect to.
    :param builtins.str organization: The name of the organization containing the targeted workspace(s).
    :param builtins.str token: The token used to authenticate with the remote backend.
    """
    __args__ = dict()
    __args__['hostname'] = hostname
    __args__['organization'] = organization
    __args__['token'] = token
    __args__['workspaces'] = workspaces
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('terraform:state:getRemoteReference', __args__, opts=opts, typ=GetRemoteReferenceResult).value

    return AwaitableGetRemoteReferenceResult(
        outputs=pulumi.get(__ret__, 'outputs'))
def get_remote_reference_output(hostname: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                organization: Optional[pulumi.Input[builtins.str]] = None,
                                token: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                workspaces: Optional[pulumi.Input[Union['Workspaces', 'WorkspacesDict']]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRemoteReferenceResult]:
    """
    Access state from a remote backend.


    :param builtins.str hostname: The remote backend hostname to connect to.
    :param builtins.str organization: The name of the organization containing the targeted workspace(s).
    :param builtins.str token: The token used to authenticate with the remote backend.
    """
    __args__ = dict()
    __args__['hostname'] = hostname
    __args__['organization'] = organization
    __args__['token'] = token
    __args__['workspaces'] = workspaces
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('terraform:state:getRemoteReference', __args__, opts=opts, typ=GetRemoteReferenceResult)
    return __ret__.apply(lambda __response__: GetRemoteReferenceResult(
        outputs=pulumi.get(__response__, 'outputs')))
